pub enum GroupCommitCertainty {
DefinitelyAborted,
Unknown,
}Expand description
Commit certainty owned by the migration journal layer.
Provider adapters must map absent certainty information to Self::Unknown.
Only an explicit provider proof that commit could not have occurred may map
to Self::DefinitelyAborted.
Variants
DefinitelyAborted
The provider proves that the group transaction did not commit.
Unknown
The provider cannot determine whether the group transaction committed.
Implementations
Sourceimpl GroupCommitCertainty
impl GroupCommitCertainty
Sourcepub const fn journal_event(self) -> GroupJournalEventKind
pub const fn journal_event(self) -> GroupJournalEventKind
Convert certainty into its durable journal event.