GroupJournalEventKind

Enum GroupJournalEventKind 

pub enum GroupJournalEventKind {
    BeforeCommit,
    Committed,
    CommitOutcomeUnknown,
    DefinitelyAborted,
    FormalOnlyAdvanced,
}
Durable commit-boundary event vocabulary for one transaction group.

Variants



BeforeCommit

The group statements completed and the commit call is about to begin.



Committed

The provider commit succeeded and exact live target semantics were observed.



CommitOutcomeUnknown

The commit response cannot prove whether durability occurred.



DefinitelyAborted

The provider proves that the transaction did not commit.



FormalOnlyAdvanced

An empty formal-only group advanced without a provider transaction.