pub struct SchemaLoweringBinding { /* private fields */ }Expand description
Fixed lowering-profile identity plus provider capabilities available to the caller.
Implementations
Sourceimpl SchemaLoweringBinding
impl SchemaLoweringBinding
Sourcepub fn new(
profile_id: SchemaLoweringProfileId,
profile_fingerprint: SchemaLoweringProfileFingerprint,
available_capabilities: CapabilitySet,
) -> Result<Self, SchemaLoweringDiagnostic>
pub fn new( profile_id: SchemaLoweringProfileId, profile_fingerprint: SchemaLoweringProfileFingerprint, available_capabilities: CapabilitySet, ) -> Result<Self, SchemaLoweringDiagnostic>
Bind caller capabilities to the exact compiled lowering profile.
Sourcepub fn current(
available_capabilities: CapabilitySet,
) -> Result<Self, SchemaLoweringDiagnostic>
pub fn current( available_capabilities: CapabilitySet, ) -> Result<Self, SchemaLoweringDiagnostic>
Bind capabilities to the current compiled profile.
Sourcepub const fn available_capabilities(&self) -> &CapabilitySet
pub const fn available_capabilities(&self) -> &CapabilitySet
Return available provider capabilities.
Sourcepub const fn profile_id(&self) -> &SchemaLoweringProfileId
pub const fn profile_id(&self) -> &SchemaLoweringProfileId
Return the exact compiled lowering-profile identity.
Sourcepub const fn profile_fingerprint(&self) -> &SchemaLoweringProfileFingerprint
pub const fn profile_fingerprint(&self) -> &SchemaLoweringProfileFingerprint
Return the exact compiled lowering-profile content fingerprint.