pub struct StatementUnit { /* private fields */ }Expand description
One preserved outer delta operation and its atomic TypeQL query sequence.
Implementations
Sourceimpl StatementUnit
impl StatementUnit
Sourcepub const fn operation_index(&self) -> usize
pub const fn operation_index(&self) -> usize
Return the zero-based index of the source delta operation.
Sourcepub const fn operation_kind(&self) -> StatementOperationKind
pub const fn operation_kind(&self) -> StatementOperationKind
Return the formal operation represented by this unit.
Sourcepub const fn safety(&self) -> SafetyClass
pub const fn safety(&self) -> SafetyClass
Return the classified safety level for the operation.
Sourcepub fn affected_ids(&self) -> &[SchemaFactId]
pub fn affected_ids(&self) -> &[SchemaFactId]
Return the canonical schema fact identities affected by the unit.
Sourcepub const fn required_capabilities(&self) -> &CapabilitySet
pub const fn required_capabilities(&self) -> &CapabilitySet
Return the provider capabilities required to execute the unit.
Sourcepub fn statements(&self) -> &[TypeQlStatement]
pub fn statements(&self) -> &[TypeQlStatement]
Return the deterministic TypeQL statements in execution order.