pub struct BackfillCompletionEvidence { /* private fields */ }Expand description
Exact terminal proof that one closed backfill program satisfies its postcondition.
Implementations
Sourceimpl BackfillCompletionEvidence
impl BackfillCompletionEvidence
Sourcepub const fn new(
plan_fingerprint: Fingerprint,
direction: BackfillExecutionDirection,
counts: BackfillExecutionCounts,
) -> Self
pub const fn new( plan_fingerprint: Fingerprint, direction: BackfillExecutionDirection, counts: BackfillExecutionCounts, ) -> Self
Bind terminal counts to one exact canonical plan and execution direction.
Sourcepub const fn plan_fingerprint(&self) -> &Fingerprint
pub const fn plan_fingerprint(&self) -> &Fingerprint
Return the exact canonical backfill-plan identity.
Sourcepub const fn direction(&self) -> BackfillExecutionDirection
pub const fn direction(&self) -> BackfillExecutionDirection
Return whether the forward or checked reverse program completed.
Sourcepub const fn counts(&self) -> BackfillExecutionCounts
pub const fn counts(&self) -> BackfillExecutionCounts
Return internally consistent aggregate counts.