pub struct BackfillExecutionCounts { /* private fields */ }Expand description
Bounded aggregate counts from a completely verified backfill execution.
Implementations
Sourceimpl BackfillExecutionCounts
impl BackfillExecutionCounts
Sourcepub fn new(
matched: u64,
changed: u64,
skipped: u64,
transaction_groups: u32,
) -> Result<Self, Diagnostic>
pub fn new( matched: u64, changed: u64, skipped: u64, transaction_groups: u32, ) -> Result<Self, Diagnostic>
Construct internally consistent terminal counts.
Sourcepub const fn matched(self) -> u64
pub const fn matched(self) -> u64
Return the number of source rows selected by the closed plan.
Sourcepub const fn skipped(self) -> u64
pub const fn skipped(self) -> u64
Return the number of already-equal rows skipped idempotently.
Sourcepub const fn transaction_groups(self) -> u32
pub const fn transaction_groups(self) -> u32
Return the number of committed deterministic transaction groups.