pub struct LegacyMigrationReference { /* private fields */ }Expand description
One legacy frontier migration named by the canonical bridge.
Implementations
Sourceimpl LegacyMigrationReference
impl LegacyMigrationReference
Sourcepub fn new(
id: impl Into<LegacyMigrationId>,
checksum: LegacyMigrationChecksum,
) -> Self
pub fn new( id: impl Into<LegacyMigrationId>, checksum: LegacyMigrationChecksum, ) -> Self
Bind one legacy compound identity to its tagged checksum.
Sourcepub const fn id(&self) -> &LegacyMigrationId
pub const fn id(&self) -> &LegacyMigrationId
Return the legacy compound migration identity.
Sourcepub const fn checksum(&self) -> &LegacyMigrationChecksum
pub const fn checksum(&self) -> &LegacyMigrationChecksum
Return the tagged legacy checksum.