pub struct MigrationDirectoryEntry { /* private fields */ }Expand description
One direct entry observed through a retained migration-directory handle.
Implementations
Sourceimpl MigrationDirectoryEntry
impl MigrationDirectoryEntry
Sourcepub const fn is_directory(&self) -> bool
pub const fn is_directory(&self) -> bool
Return whether this entry was observed as a directory.
Sourcepub const fn is_regular(&self) -> bool
pub const fn is_regular(&self) -> bool
Return whether this entry was observed as a regular file.