MigrationExecutionReport

Struct MigrationExecutionReport 

pub struct MigrationExecutionReport { /* private fields */ }
Bounded owned projection of one terminal apply or rollback outcome.

Implementations

Source

impl MigrationExecutionReport

pub const fn direction(&self) -> MigrationExecutionDirection

Return the execution direction.

pub const fn status(&self) -> MigrationExecutionStatus

Return the terminal status.

pub const fn migration_id(&self) -> Option<&MigrationId>

Return the interrupted migration identity, when execution did not complete.

pub const fn position(&self) -> Option<MigrationExecutionReportPosition>

Return the exact interrupted execution position, when present.

pub const fn diagnostic(&self) -> Option<&Diagnostic>

Return the canonical privacy-safe diagnostic, when present.

pub fn backfills(&self) -> &[MigrationBackfillObservation]

Return ordered terminal observations for completed canonical backfills.

pub fn from_apply(outcome: MigrationExecutionOutcome) -> Self

Consume a forward coordinator outcome into its bounded public projection.

pub fn from_rollback(outcome: MigrationRollbackOutcome) -> Self

Consume a rollback coordinator outcome into its bounded public projection.