pub struct VerifiedMigrationHistoryBundleEntry { /* private fields */ }Expand description
One replay-verified historical manifest and its exact endpoint schemas.
Implementations
Sourceimpl VerifiedMigrationHistoryBundleEntry
impl VerifiedMigrationHistoryBundleEntry
Sourcepub const fn manifest(&self) -> &VerifiedSchemaMigrationManifest
pub const fn manifest(&self) -> &VerifiedSchemaMigrationManifest
Return the verified manifest.
Sourcepub const fn manifest_digest(&self) -> MigrationManifestDigest
pub const fn manifest_digest(&self) -> MigrationManifestDigest
Return the raw digest of the exact canonical manifest bytes.
Sourcepub const fn source_schema(&self) -> &DeclaredSchema
pub const fn source_schema(&self) -> &DeclaredSchema
Return the historical declared schema required before this manifest.
Sourcepub const fn target_schema(&self) -> &DeclaredSchema
pub const fn target_schema(&self) -> &DeclaredSchema
Return the historical declared schema produced by this manifest.