pub struct VerifiedMigrationTransactionGroup { /* private fields */ }Expand description
One verifier-owned transaction group ending in exactly one schema delta.
Implementations
Sourceimpl VerifiedMigrationTransactionGroup
impl VerifiedMigrationTransactionGroup
Sourcepub const fn first_step_index(&self) -> usize
pub const fn first_step_index(&self) -> usize
Return the first assertion index, or the delta index when there are none.
Sourcepub const fn schema_delta_step_index(&self) -> usize
pub const fn schema_delta_step_index(&self) -> usize
Return the index of the group’s single terminal schema delta.
Sourcepub const fn assertion_count(&self) -> usize
pub const fn assertion_count(&self) -> usize
Return the number of assertions executed before the schema delta.
Sourcepub const fn end_step_index(&self) -> usize
pub const fn end_step_index(&self) -> usize
Return the exclusive end of this group’s step range.