pub struct VerifiedMigrationRollbackStep { /* private fields */ }Expand description
One lowered reverse program for one forward schema step.
Implementations
Sourceimpl VerifiedMigrationRollbackStep
impl VerifiedMigrationRollbackStep
Sourcepub const fn forward_step_id(&self) -> &MigrationStepId
pub const fn forward_step_id(&self) -> &MigrationStepId
Return the identity of the forward step this program reverses.
Sourcepub const fn lowering(&self) -> &SchemaLoweringPlan
pub const fn lowering(&self) -> &SchemaLoweringPlan
Return the lowered reverse statement plan.